import requests
class RetrieverVectorDB:

    @staticmethod
    def retriever(num_docs,url,query):
        data = {'num_docs': num_docs, 'query': query}
        # Send the POST request
        response = requests.post(url, json=data)
        return response.json().get('relevant_documents')



from setuptools import setup, find_packages

setup(
    name='RetrieverVectorDB',
    version='0.4',
    description='A simple Python library for retreiving documents from vectorDB.',
    author='Nitya Shah',
    packages=find_packages(),
)